!*****************************************************************************
! File    : PDFChart.inc
! Author  : Utility Warrior, (c) 2005-2007
! Project : PDF Chart Creator (PDFChart) Dynamic Link Library
! Purpose : This file provides Clarion prototypes for all DLL functions
!
! Notes   : To use the PDF Chart Creator DLL with Clarion you will need to use the Clarion 
! specific files as outlined below:
!
! Put "PDFChart Clarion.lib", "PDFChart.inc" and "PDFChart.DLL" into your Clarion 
! application directory 
!
! Load your Clarion Application into the Clarion IDE 
!
! Under Project/Properties > "Library, object, and resource files", press the 
! "Add File" button to add "PDFChart Clarion.lib" 
!
! Under Application/Global/Embeds > "Inside the Global Map", add: INCLUDE('PDFChart.inc') 
!
! NB. When you distribute your Clarion application executable ensure that you also include "PDFChart.dll"
!
! Please refer to the accompanying documentation for full details.
!******************************************************************************

  MODULE('PDFChart.dll')

!******************************************************************************
  PDFC_GetDLLVersion(),ULONG,C,RAW,Name('PDFC_GetDLLVersion')
!******************************************************************************
! This allows the support of multiple versions of a DLL (if and when
! available) so that functions that might only be available in a later version
! can then only be called if the returned version currently being used is one 
! that supports those functions.
!   
! Return value: integer value representing the DLL version, a value of 100 is
!               equivalent to version 1.00
!******************************************************************************


!******************************************************************************
! Required and Miscellaneous
!******************************************************************************


!******************************************************************************
  PDFC_License(*CSTRING code),C,RAW,Name('PDFC_License')
!******************************************************************************
! This is required to remove the "Evaluation Mode" message that is stamped 
! over the top of every page in the output PDF document.   
!   
! To purchase a license code please visit the Utility Warrior web site which 
! has the latest information and prices on the licenses that are available. 
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  PDFC_Chart(ULONG type),ULONG,C,RAW,Name('PDFC_Chart')
!******************************************************************************
! Specify which chart type is to be generated.
!
! Values that can be passed as parameters
! CHART_BAR_VERTICAL   1
! CHART_BAR_HORIZONTAL 2
! CHART_PIE_2D         3
! CHART_LINE_STANDARD  4
! CHART_LINE_STEPPED   5
! CHART_LINE_CURVED    6
! CHART_AREA_STANDARD  7
! CHART_AREA_STEPPED   8
! CHART_AREA_CURVED    9
!
! Return value:
! 0 - success
! 1 - invalid chart type
!******************************************************************************


!******************************************************************************
  PDFC_Page(ULONG width, ULONG height, REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_Page')
!******************************************************************************
! Specify page size and background color
!
! Width and height must be between 100 and 10000 inclusive
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - width invalid
! 2 - height invalid
! 3 - red invalid
! 4 - green invalid
! 5 - blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_PageName(*CSTRING name, ULONG landscape, REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_PageName')
!******************************************************************************
! Specify page size using common name and background color
!
! name must be one of: A0, A1, A2, A3, A4, A5, B0, B1, B2, B3, B4, B5, Letter, Tabloid, Ledger, Executive, Legal, Folio, Foolscap, Quarto, Statement
!
! landscape swaps rotates the page size - 0 = portrait, 1 = landscape
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - name invalid
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_DataSet(*CSTRING filename),ULONG,C,RAW,Name('PDFC_DataSet')
!******************************************************************************
! Load in chart data from an external file - either this and/or an appropriate chart
! type datum function must be used in order to define at least one item of data
!
! Up to 1000 data items can be added.
!
! Return value:
! 0 - success
! 1 - no chart type specified
! 2 - could not open filename
! 3 - maximum number of data items reached
! 101...
!     - line (101 - 100), ie line 1 contains invalid data
!******************************************************************************


!******************************************************************************
  PDFC_DataSeparator(*CSTRING separator),ULONG,C,RAW,Name('PDFC_DataSeparator')
!******************************************************************************
! Set the data separator text that is used to delineate data fields when loading in data 
! from an external file, by default this is a comma
!
! A maximum of 10 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_DataSort(ULONG field, ULONG order),ULONG,C,RAW,Name('PDFC_DataSort')
!******************************************************************************
! Specify that the data items are to be sorted before being displayed within the chart
!
! field must be either 1 or 2
!
! Values that can be passed as parameters:
! OPTION_NONE      0
! OPTION_OPEN_PDF  1
! OPTION_RESET     2
! SORT_ASCENDING   1
! SORT_DESCENDING  2
!
! Return value:
! 0 - success
! 1 - field invalid
! 2 - order invalid
!******************************************************************************


!******************************************************************************
  PDFC_Log(*CSTRING logFilename),ULONG,C,RAW,Name('PDFC_Log')
!******************************************************************************
! Information and error messages are appended to the end of the file specified (with a timestamp).
!
! Return value:
! 0 - success
! 1 - invalid logFilename
!******************************************************************************


!******************************************************************************
! Area Chart Specific
!******************************************************************************


!******************************************************************************
  PDFC_AreaDatum(*CSTRING label, REAL value),ULONG,C,RAW,Name('PDFC_AreaDatum')
!******************************************************************************
! Add an item of area data.
!
! Up to 1000 data items can be added.
!
! Return value:
! 0 - success
! 1 - area chart type not specified
! 2 - maximum number of data items already reached
! 3 - label invalid
!******************************************************************************


!******************************************************************************
  PDFC_Area(REAL lineRed, REAL lineGreen, REAL lineBlue, REAL lineThickness, REAL fillRed, REAL fillGreen, REAL fillBlue),ULONG,C,RAW,Name('PDFC_Area')
!******************************************************************************
! Specifies how the area under the data points is to be filled.
!
! Return value:
! 0 - success
! 1 - invalid lineRed
! 2 - invalid lineGreen
! 3 - invalid lineBlue
! 4 - invalid lineThickness
! 5 - invalid fillRed
! 6 - invalid fillGreen
! 7 - invalid fillBlue
!******************************************************************************


!******************************************************************************
! Line Chart Specific
!******************************************************************************


!******************************************************************************
  PDFC_LineDatum(*CSTRING label, REAL value),ULONG,C,RAW,Name('PDFC_LineDatum')
!******************************************************************************
! Add an item of line data.
!
! Up to 1000 data items can be added.
!
! Return value:
! 0 - success
! 1 - line chart type not specified
! 2 - maximum number of data items already reached
! 3 - label invalid
!******************************************************************************


!******************************************************************************
  PDFC_Line(REAL lineRed, REAL lineGreen, REAL lineBlue, REAL lineThickness),ULONG,C,RAW,Name('PDFC_Line')
!******************************************************************************
! Specifies the line color and thickness that connects all of the data points together.
!
! Return value:
! 0 - success
! 1 - invalid lineRed
! 2 - invalid lineGreen
! 3 - invalid lineBlue
! 4 - invalid lineThickness
!******************************************************************************


!******************************************************************************
  PDFC_LineMarker(REAL markerRed, REAL markerGreen, REAL markerBlue, REAL size, ULONG markerStyle, REAL outlineThickness),ULONG,C,RAW,Name('LineMarker')
!******************************************************************************
! Specifies a marker to be displayed on the line at the data point position.
!
! markerStyle must be one of the following values:
! LINE_POINT_STYLE_FILLED_CIRCLE		1
! LINE_POINT_STYLE_OUTLINE_CIRCLE		2
! LINE_POINT_STYLE_FILLED_SQUARE		3
! LINE_POINT_STYLE_OUTLINE_SQUARE		4
! LINE_POINT_STYLE_CROSS				5
! LINE_POINT_STYLE_FILLED_DIAMOND		6
! LINE_POINT_STYLE_OUTLINE_DIAMOND		7
!
! Return value:
! 0 - success
! 1 - invalid markerRed
! 2 - invalid markerGreen
! 3 - invalid markerBlue
! 4 - invalid size
! 5 - invalid markerStyle
! 6 - invalid outlineThickness
!******************************************************************************


!******************************************************************************
! Bar Chart Specific
!******************************************************************************


!******************************************************************************
  PDFC_BarDatum(*CSTRING label, REAL value),ULONG,C,RAW,Name('PDFC_BarDatum')
!******************************************************************************
! Add an item of bar data.
!
! Up to 1000 data items can be added.
!
! Return value:
! 0 - success
! 1 - bar chart type not specified
! 2 - maximum number of data items already reached
! 3 - label invalid
!******************************************************************************


!******************************************************************************
  PDFC_BarColor(REAL fromRed, REAL fromGreen, REAL fromBlue, REAL toRed, REAL toGreen, REAL toBlue),ULONG,C,RAW,Name('PDFC_BarColor')
!******************************************************************************
! Sets a color (range) for a bar
!
! Up to 50 bar colors can be defined
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - maximum number of bar colors already specified
! 2 - from red invalid
! 3 - from green invalid
! 4 - from blue invalid
! 5 - to red invalid
! 6 - to green invalid
! 7 - to blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_BarSpacing(ULONG spacing),ULONG,C,RAW,Name('PDFC_BarSpacing')
!******************************************************************************
! Sets the amount of spacing between bars (bar size automatically calculated from this)
!
! Return value:
! 0 - success
! 1 - invalid spacing, must be between 0 and 500 inclusive
!******************************************************************************


!******************************************************************************
  PDFC_BarSize(ULONG size),ULONG,C,RAW,Name('PDFC_BarSize')
!******************************************************************************
! Sets the bar size (bar spacing automatically calculated from this)
!
! Return value:
! 0 - success
! 1 - invalid size, must be between 1 and 500 inclusive
!******************************************************************************


!******************************************************************************
  PDFC_BarLabel(ULONG labelPosition, *CSTRING format),ULONG,C,RAW,Name('PDFC_BarLabel')
!******************************************************************************
! Set the position and label style
!
! Values that can be passed as parameters:
! LABEL_AT_START           1
! LABEL_AT_END             2
! LABEL_AT_CENTER          3
! LABEL_AT_AXES            4
! LABEL_AT_AXES_AND_START  5
! LABEL_AT_AXES_AND_END    6
! LABEL_AT_AXES_AND_CENTER 7
!
! Return value:
! 0 - success
! 1 - label position not valid
! 2 - invalid format
!******************************************************************************


!******************************************************************************
  PDFC_BarBorder(REAL width, REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_BarBorder')
!******************************************************************************
! Set the bar border width and color
!
! width must be > 0.0 and <= 100.0
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! 0 - success
! 1 - width invalid
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
!******************************************************************************


!******************************************************************************
! Axes and Labels
!******************************************************************************


!******************************************************************************
  PDFC_ChartBackground(REAL fromRed, REAL fromGreen, REAL fromBlue, REAL toRed, REAL toGreen, REAL toBlue),ULONG,C,RAW,Name('PDFC_ChartBackground')
!******************************************************************************
! Sets the background color (range) for the chart
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - from red invalid
! 2 - from green invalid
! 3 - from blue invalid
! 4 - to red invalid
! 5 - to green invalid
! 6 - to blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_ChartHeading(ULONG verticalAlignment, ULONG horizontalAlignment),ULONG,C,RAW,Name('PDFC_ChartHeading')
!******************************************************************************
! Sets the chart heading position
!
! verticalAlignment Value must be one of the following values:
! VERTICAL_ALIGNMENT_TOP    1
! VERTICAL_ALIGNMENT_BOTTOM 3
! NB vertical alignment must be either top or bottom (NOT middle)
!
! horizontalAlignment Value must be one of the following values:
! HORIZONTAL_ALIGNMENT_LEFT   1
! HORIZONTAL_ALIGNMENT_CENTER 2
! HORIZONTAL_ALIGNMENT_RIGHT  3
!
! Return value:
! 0 - success
! 1 - vertical alignment invalid
! 2 - horizontal alignment invalid
!******************************************************************************


!******************************************************************************
  PDFC_HeadingTitle(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_HeadingTitle')
  PDFC_HeadingSubTitle(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_HeadingSubTitle')
  PDFC_AxesLabelX(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_AxesLabelX')
  PDFC_AxesLabelY(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_AxesLabelY')
!******************************************************************************
! size must be between 1 and 300 inclusive
!
! fontID must be one of the following values:
! FONT_ID_COURIER               1
! FONT_ID_COURIER_BOLD          2
! FONT_ID_COURIER_BOLDOBLIQUE   3
! FONT_ID_COURIER_OBLIQUE       4
! FONT_ID_HELVETICA             5
! FONT_ID_HELVETICA_BOLD        6
! FONT_ID_HELVETICA_BOLDOBLIQUE 7
! FONT_ID_HELVETICA_OBLIQUE     8
! FONT_ID_TIMES_ROMAN           9
! FONT_ID_TIMES_BOLD            10
! FONT_ID_TIMES_ITALIC          11
! FONT_ID_TIMES_BOLDITALIC      12
! FONT_ID_SYMBOL                13
! FONT_ID_ZAPFDINGBATS          14
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! style must be one of the following values:
! TEXT_STYLE_NORMAL  1
! TEXT_STYLE_STROKE  2
!
! other color is only required if the style is stroke
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font 
! 3 - fill red invalid
! 4 - fill green invalid
! 5 - fill blue invalid
! 6 - invalid style
! 7 - other red invalid
! 8 - other green invalid
! 9 - other blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_AxesCaptionX(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue, ULONG horizontalAlignment, *CSTRING label),ULONG,C,RAW,Name('PDFC_AxesCaptionX')
!******************************************************************************
! size must be between 1 and 300 inclusive
!
! fontID must be one of the following values:
! FONT_ID_COURIER               1
! FONT_ID_COURIER_BOLD          2
! FONT_ID_COURIER_BOLDOBLIQUE   3
! FONT_ID_COURIER_OBLIQUE       4
! FONT_ID_HELVETICA             5
! FONT_ID_HELVETICA_BOLD        6
! FONT_ID_HELVETICA_BOLDOBLIQUE 7
! FONT_ID_HELVETICA_OBLIQUE     8
! FONT_ID_TIMES_ROMAN           9
! FONT_ID_TIMES_BOLD            10
! FONT_ID_TIMES_ITALIC          11
! FONT_ID_TIMES_BOLDITALIC      12
! FONT_ID_SYMBOL                13
! FONT_ID_ZAPFDINGBATS          14
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! style must be one of the following values:
! TEXT_STYLE_NORMAL  1
! TEXT_STYLE_STROKE  2
!
! other color is only required if the style is stroke
!
! horizontalAlignment Value must be one of the following values:
! HORIZONTAL_ALIGNMENT_LEFT   1
! HORIZONTAL_ALIGNMENT_CENTER 2
! HORIZONTAL_ALIGNMENT_RIGHT  3
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font 
! 3 - fill red invalid
! 4 - fill green invalid
! 5 - fill blue invalid
! 6 - invalid style
! 7 - other red invalid
! 8 - other green invalid
! 9 - other blue invalid
! 10 - invalid horizontal alignment
! 11 - label is invalid
!******************************************************************************


!******************************************************************************
  PDFC_AxesCaptionY(ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue, ULONG verticalAlignment, *CSTRING label),ULONG,C,RAW,Name('PDFC_AxesCaptionY')
!******************************************************************************
! size must be between 1 and 300 inclusive
!
! fontID must be one of the following values:
! FONT_ID_COURIER               1
! FONT_ID_COURIER_BOLD          2
! FONT_ID_COURIER_BOLDOBLIQUE   3
! FONT_ID_COURIER_OBLIQUE       4
! FONT_ID_HELVETICA             5
! FONT_ID_HELVETICA_BOLD        6
! FONT_ID_HELVETICA_BOLDOBLIQUE 7
! FONT_ID_HELVETICA_OBLIQUE     8
! FONT_ID_TIMES_ROMAN           9
! FONT_ID_TIMES_BOLD            10
! FONT_ID_TIMES_ITALIC          11
! FONT_ID_TIMES_BOLDITALIC      12
! FONT_ID_SYMBOL                13
! FONT_ID_ZAPFDINGBATS          14
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! style must be one of the following values:
! TEXT_STYLE_NORMAL  1
! TEXT_STYLE_STROKE  2
!
! other color is only required if the style is stroke
!
! verticalAlignment Value must be one of the following values:
! VERTICAL_ALIGNMENT_TOP    1
! VERTICAL_ALIGNMENT_MIDDLE 2
! VERTICAL_ALIGNMENT_BOTTOM 3
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font 
! 3 - fill red invalid
! 4 - fill green invalid
! 5 - fill blue invalid
! 6 - invalid style
! 7 - other red invalid
! 8 - other green invalid
! 9 - other blue invalid
! 10 - invalid vertical alignment
! 11 - label is invalid
!******************************************************************************


!******************************************************************************
  PDFC_AxesLine(REAL width, REAL red, REAL green, REAL blue, ULONG format),ULONG,C,RAW,Name('PDFC_AxesLine')
!******************************************************************************
! Sets the width, color and style for the axes boundary lines surrounding the chart area
!
! width must be between 0.1 and 100.0 inclusive
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! format must be one of the following values:
!
! AXES_LINE_XY	 1
! AXES_LINE_FULL 2
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
! 5 - invalid line format
!******************************************************************************


!******************************************************************************
  PDFC_AxesScale(ULONG scale, REAL value1, REAL value2),ULONG,C,RAW,Name('PDFC_AxesScale')
!******************************************************************************
! Sets the width, color and style for the axes boundary lines surrounding the chart area
!
! scale must be one of the following values:
! AXES_SCALE_FROM_ZERO		    1
! AXES_SCALE_UNDER_LOWEST_VALUE	2
! AXES_SCALE_RANGE		        3
! AXES_SCALE_EITHER_SIDE        4
!
! if scale is AXES_SCALE_FROM_ZERO then value1 and value2 are not used
! if scale is AXES_SCALE_UNDER_LOWEST_VALUE then value1 is an integer percentage from 0 to 100%, value2 is not used
! if scale is AXES_SCALE_RANGE then the axes range is from value1 to value2
!
! Return value:
! 0 - success
! 1 - invalid scale type
! 2 - invalid percentage
!******************************************************************************


!******************************************************************************
  PDFC_AxesDivisions(ULONG divisions),ULONG,C,RAW,Name('PDFC_AxesDivisions')
!******************************************************************************
! Sets the number of divisions in the axes scale
!
! divisions must be between 1 and 100 inclusive
!
! Return value:
! 0 - success
! 1 - invalid divisions
!******************************************************************************


!******************************************************************************
  PDFC_DecimalPoints(ULONG points),ULONG,C,RAW,Name('PDFC_DecimalPoints')
!******************************************************************************
! Sets the number of decimal points to be displayed with a real number
!
! points must be between 0 and 9 inclusive
!
! Return value:
! 0 - success
! 1 - invalid points
!******************************************************************************


!******************************************************************************
  PDFC_AxesGridLineStyle(ULONG dash, ULONG gap, ULONG offset),ULONG,C,RAW,Name('PDFC_AxesGridLineStyle')
!******************************************************************************
! Sets the dashed line style for the grid lines
!
! all parameters must be between 0 and 100 inclusive
!
! Return value:
! 0 - success
! 1 - invalid dash
! 2 - invalid gap
! 3 - invalid offset
!******************************************************************************


!******************************************************************************
  PDFC_AxesGridLine(REAL width, REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_AxesGridLine')
!******************************************************************************
! Sets the width and color of the axes grid lines that are drawn within the chart area
!
! width must be between 0.1 and 100.0 inclusive
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_AxesLabelYPosition(ULONG position),ULONG,C,RAW,Name('PDFC_AxesLabelYPosition')
!******************************************************************************
! Controls which side of the chart the Y axis label is displayed
!
! position must be one of the following values:
! AXES_LABEL_Y_POSITION_TO_LEFT  1
! AXES_LABEL_Y_POSITION_TO_RIGHT 2
!
! Return value:
! 0 - success
! 1 - invalid position
!******************************************************************************


!******************************************************************************
  PDFC_AxesLabelSpacing(ULONG nth),ULONG,C,RAW,Name('PDFC_AxesLabelSpacing')
!******************************************************************************
! Controls the display of the X axis data labels (if the chart type supports this)
! so that it displays every nth label on the axes which is useful if there are a 
! lot of labels to display which would otherwise overwrite each other
!
! nth must be between 1 and 50 inclusive
!
! Return value:
! 0 - success
! 1 - nth is invalid
!******************************************************************************


!******************************************************************************
! Pie Chart Specific
!******************************************************************************


!******************************************************************************
  PDFC_PieDatum(*CSTRING label, REAL value),ULONG,C,RAW,Name('PDFC_PieDatum')
!******************************************************************************
! Add an item of pie data.
!
! Up to 1000 data items can be added.
!
! Return value:
! 0 - success
! 1 - pie chart type not specified
! 2 - maximum number of data items already reached
! 3 - label invalid
!******************************************************************************


!******************************************************************************
  PDFC_PieColor(REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_PieColor')
!******************************************************************************
! Sets a color for a pie segment
!
! Up to 50 bar colors can be defined
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - maximum number of pie colors already specified
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_PieOutline(REAL borderWidth, REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('PDFC_PieOutline')
!******************************************************************************
! Sets a color for a pie segment
!
! borderWidth must be between 0.0 and 100.0 inclusive
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
!
! Return value:
! 0 - success
! 1 - border width invalid
! 2 - red invalid
! 3 - green invalid
! 4 - blue invalid
!******************************************************************************


!******************************************************************************
  PDFC_PiePageMargin(REAL marginSize),ULONG,C,RAW,Name('PDFC_PiePageMargin')
!******************************************************************************
! Sets the minimum spacing between the edge of the page and the chart
!
! marginSize must be between 0.0 and 100.0 inclusive
!
! Return value:
! 0 - success
! 1 - margin size invalid
!******************************************************************************


!******************************************************************************
  PDFC_PieLabel(ULONG labelPosition, *CSTRING format, ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_PieLabel')
!******************************************************************************
! Sets the label text style
!
! labelPosition must be ones of the following values:
! LABEL_INSIDE	8
! LABEL_OUTSIDE	9
! LABEL_SPOKE	10
!
! format
!
! size must be between 1 and 300 inclusive
!
! fontID must be one of the following values:
! FONT_ID_COURIER               1
! FONT_ID_COURIER_BOLD          2
! FONT_ID_COURIER_BOLDOBLIQUE   3
! FONT_ID_COURIER_OBLIQUE       4
! FONT_ID_HELVETICA             5
! FONT_ID_HELVETICA_BOLD        6
! FONT_ID_HELVETICA_BOLDOBLIQUE 7
! FONT_ID_HELVETICA_OBLIQUE     8
! FONT_ID_TIMES_ROMAN           9
! FONT_ID_TIMES_BOLD            10
! FONT_ID_TIMES_ITALIC          11
! FONT_ID_TIMES_BOLDITALIC      12
! FONT_ID_SYMBOL                13
! FONT_ID_ZAPFDINGBATS          14
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! style must be one of the following values:
! TEXT_STYLE_NORMAL  1
! TEXT_STYLE_STROKE  2
!
! other color is only required if the style is stroke
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font 
! 3 - fill red invalid
! 4 - fill green invalid
! 5 - fill blue invalid
! 6 - invalid style
! 7 - other red invalid
! 8 - other green invalid
! 9 - other blue invalid
! 10 - invalid label format
! 11 - invalid label position
!******************************************************************************


!******************************************************************************
! Legends
!******************************************************************************

!******************************************************************************
  PDFC_Legend(ULONG legendPosition, *CSTRING format, REAL outlineRed, REAL outlineGreen, REAL outlineBlue, REAL outlineWidth, REAL backgroundRed, REAL backgroundGreen, REAL backgroundBlue, ULONG size, ULONG fontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG style, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('PDFC_Legend')
!******************************************************************************
! Legend box settings
!
! legendPosition must be one of the following values:
! LEGEND_NONE	0
! LEGEND_ABOVE	1
! LEGEND_BELOW	2
! LEGEND_LEFT	3
! LEGEND_RIGHT	4
!
! format
!
! Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
!
! size must be between 1 and 300 inclusive
!
! other color is only required if the style is stroke
!
! Return value:
! 0 - success
! 1 - legend position invalid
! 2 - outline red invalid
! 3 - outline green invalid
! 4 - outline blue invalid
! 5 - invalid outline width
! 6 - background red invalid
! 7 - background green invalid
! 8 - background blue invalid
! 9 - invalid legend format
! 10 - invalid size
! 11 - invalid font 
! 12 - fill red invalid
! 13 - fill green invalid
! 14 - fill blue invalid
! 15 - invalid style
! 16 - other red invalid
! 17 - other green invalid
! 18 - other blue invalid
!******************************************************************************


!******************************************************************************
! Numerical Analyses
!******************************************************************************

!******************************************************************************
  PDFC_LineOfBestFit(REAL lineRed, REAL lineGreen, REAL lineBlue, REAL lineThickness),ULONG,C,RAW,Name('PDFC_LineOfBestFit')
!******************************************************************************
! Specifies the line thickness and color that is used to display the "line of best fit".
!
! Return value:
! 0 - success
! 1 - invalid lineRed
! 2 - invalid lineGreen
! 3 - invalid lineBlue
! 4 - invalid lineThickness
!******************************************************************************
	

!******************************************************************************
  PDFC_MovingAverageLine(ULONG samplePoints, REAL lineRed, REAL lineGreen, REAL lineBlue, REAL lineThickness),ULONG,C,RAW,Name('PDFC_MovingAverageLine')
!******************************************************************************
! The moving average at any given point is the average of that point and the preceeding <samplePoints - 1> data items.
! This means that the first moving average point that can be plotted is not at the first position on the chart but at the <samplePoints> position.
!
! Return value:
! 0 - success
! 1 - invalid lineRed
! 2 - invalid lineGreen
! 3 - invalid lineBlue
! 4 - invalid lineThickness
! 5 - invalid samples
!******************************************************************************


!******************************************************************************
  PDFC_MovingAverageLineMarker(ULONG markerStyle, REAL markerRed, REAL markerGreen, REAL markerBlue, REAL markerSize, REAL outlineThickness),ULONG,C,RAW,Name('PDFC_MovingAverageLineMarker')
!******************************************************************************
! This is optional and specifies a marker to be displayed on the moving average line at the data point position.
!
! Values that can be passed as parameters
! LINE_POINT_STYLE_FILLED_CIRCLE		1
! LINE_POINT_STYLE_OUTLINE_CIRCLE		2
! LINE_POINT_STYLE_FILLED_SQUARE		3
! LINE_POINT_STYLE_OUTLINE_SQUARE		4
! LINE_POINT_STYLE_CROSS				5
! LINE_POINT_STYLE_FILLED_DIAMOND		6
! LINE_POINT_STYLE_OUTLINE_DIAMOND	7
!
! Return value:
! 0 - success
! 1 - invalid markerStyle
! 2 - invalid markerRed
! 3 - invalid markerGreen
! 4 - invalid markerBlue
! 5 - invalid markerSize
! 6 - invalid outlineThickness
!******************************************************************************


!******************************************************************************
! PDF Settings
!******************************************************************************


!******************************************************************************
  PDFC_SetOutline(ULONG format, ULONG style),ULONG,C,RAW,Name('PDFC_SetOutline')
!******************************************************************************
! This turns on the generation of a bookmark for each image that is in the 
! output PDF document.
!
! Values that can be passed as parameters
! OUTLINE_FORMAT_FILENAME  1
! OUTLINE_FORMAT_NAME      2
! STYLE_NONE               0
! STYLE_LOWERCASE          1
! STYLE_UPPERCASE          2
! STYLE_CAPITALISE         3
!
! format can be either "filename" (this is the name of the image file including 
! the image extension but not including the full filepath) or "name" (same as 
! filename but without the image extension).
!
! style can be: "lowercase", "uppercase", "capitalise" or "none".
!
! Return value:
! 0 - success
! 1 - invalid format parameter
! 2 - invalid style parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetPermissions(ULONG iPermissions),ULONG,C,RAW,Name('PDFC_SetPermissions')
!******************************************************************************
! Allows the setting of any combination of permissions in one go
!
! Values that can be passed as parameters
! PDF_PERMISSION_READ_ONLY    0
! PDF_PERMISSION_EDIT         1 
! PDF_PERMISSION_EDIT_EXTRA   2
! PDF_PERMISSION_COPY         4
! PDF_PERMISSION_PRINT        8
!
! Return value:
! 0 - success
! 1 - invalid permissions
!******************************************************************************


!******************************************************************************
  PDFC_SetPermissionEdit(),C,RAW,Name('PDFC_SetPermissionEdit')
!******************************************************************************
! Allows editing/changing of the PDF document but NOT adding or changing of text 
! notes and AcroForm fields.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  PDFC_SetPermissionEditExtra(),C,RAW,Name('PDFC_SetPermissionEditExtra')
!******************************************************************************
! Allows the adding and changing of text notes and AcroForm fields within a PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  PDFC_SetPermissionCopy(),C,RAW,Name('PDFC_SetPermissionCopy')
!******************************************************************************
! Allows the copying of text and graphics from the PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  PDFC_SetPermissionPrint(),C,RAW,Name('PDFC_SetPermissionPrint')
!******************************************************************************
! Allows printing of the PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  PDFC_SetOwnerPassword(*CSTRING password),ULONG,C,RAW,Name('PDFC_SetOwnerPassword')
!******************************************************************************
! The owner of a PDF document would enter this password in order to view it
! and make changes and perform actions that may be restricted to a normal user.
!
! A maximum of 32 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetUserPassword(*CSTRING password),ULONG,C,RAW,Name('PDFC_SetUserPassword')
!******************************************************************************
! In order that only the intended user can view the PDF document, they must type
! in this password, otherwise the user is not allowed to read the PDF document.
!
! A maximum of 32 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************



!******************************************************************************
! PDF Meta Information
!******************************************************************************


!******************************************************************************
  PDFC_SetProducer(*CSTRING producer),ULONG,C,RAW,Name('PDFC_SetProducer')
!******************************************************************************
! The name of the application that converted the document from its native format to PDF.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetCreator(*CSTRING creator),ULONG,C,RAW,Name('PDFC_SetCreator')
!******************************************************************************
! If the document was converted into a PDF document from another form, this is 
! usually the name of the application that created the original document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetAuthor(*CSTRING author),ULONG,C,RAW,Name('PDFC_SetAuthor')
!******************************************************************************
! The name of the person who created the PDF document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetTitle(*CSTRING title),ULONG,C,RAW,Name('PDFC_SetTitle')
!******************************************************************************
! The PDF document's title.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetSubject(*CSTRING subject),ULONG,C,RAW,Name('PDFC_SetSubject')
!******************************************************************************
! The PDF document's subject.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetKeywords(*CSTRING keywords),ULONG,C,RAW,Name('PDFC_SetKeywords')
!******************************************************************************
! A list of keywords associated with the PDF document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  PDFC_SetCreationDate(),C,RAW,Name('PDFC_SetCreationDate')
!******************************************************************************
! The date that the PDF document was created.
!
! This is set using the current local time of the PC.
!
! Return value: none
!******************************************************************************


!******************************************************************************
! PDF Viewer Preferences
!******************************************************************************


!******************************************************************************
  PDFC_SetViewerPreferenceCenterWindow(),C,RAW,Name('PDFC_SetViewerPreferenceCenterWindow')
!******************************************************************************
! The window displaying the PDF document should be displayed in the center of 
! the computer's screen.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetViewerPreferenceHideToolbar(),C,RAW,Name('PDFC_SetViewerPreferenceHideToolbar')
!******************************************************************************
! The PDF viewer's toolbar should be hidden when the PDF document is active.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetViewerPreferenceHideMenubar(),C,RAW,Name('PDFC_SetViewerPreferenceHideMenubar')
!******************************************************************************
! The PDF viewer's menubar should be hidden when the PDF document is active.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetViewerPreferenceHideWindowUI(),C,RAW,Name('PDFC_SetViewerPreferenceHideWindowUI')
!******************************************************************************
! The user interface elements within the PDF document's window should be hidden.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetViewerPreferenceFitWindow(),C,RAW,Name('PDFC_SetViewerPreferenceFitWindow')
!******************************************************************************
! The PDF viewer should resize the window displaying the PDF document to fit the 
! size of the first displayed page of the PDF document.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageModeOutlines(),C,RAW,Name('PDFC_SetPageModeOutlines')
!******************************************************************************
! The PDF viewer should show the outline (ie bookmark) navigation item when the 
! PDF document is open.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageModeNone(),C,RAW,Name('PDFC_SetPageModeNone')
!******************************************************************************
! The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
! items when the PDF document is open.
!
! This is the default if no other page mode is specified.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageModeUseThumbs(),C,RAW,Name('PDFC_SetPageModeUseThumbs')
!******************************************************************************
! The PDF viewer should show the thumbnail navigation item when the PDF document 
! is open.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageModeFullScreen(),C,RAW,Name('PDFC_SetPageModeFullScreen')
!******************************************************************************
! The PDF viewer should open the PDF document in full-screen mode without showing 
! the menu bar, window controls or any other window.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageLayoutSinglePage(),C,RAW,Name('PDFC_SetPageLayoutSinglePage')
!******************************************************************************
! Display the pages one page at a time.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageLayoutOneColumn(),C,RAW,Name('PDFC_SetPageLayoutOneColumn')
!******************************************************************************
! Display the pages in one column.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageLayoutTwoColumnLeft(),C,RAW,Name('PDFC_SetPageLayoutTwoColumnLeft')
!******************************************************************************
! Display the pages in two columns, with odd-numbered pages on the left.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  PDFC_SetPageLayoutTwoColumnRight(),C,RAW,Name('PDFC_SetPageLayoutTwoColumnRight')
!******************************************************************************
! Display the pages in two columns, with odd-numbered pages on the right.
!
! Return value: none
!******************************************************************************


!******************************************************************************
! Specifies the name and location of the produced PDF document
!******************************************************************************

!******************************************************************************
  PDFC_MakePDF(*CSTRING output, ULONG options, *CSTRING errorText, ULONG maxErrorTextSize),ULONG,C,RAW,Name('PDFC_MakePDF')
!******************************************************************************
! Generate the output PDF according to the settings already selected through
! the Application Programming Interface functions above.
!
! To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
! bit flag in the options parameter.
!
! To have all settings applied reset after PDF has been generated set the OPTION_RESET
! bit flag in the options parameter.
!
! Values that can be passed as parameters
! OPTION_NONE      0
! OPTION_OPEN_PDF  1
! OPTION_RESET     2
!
! Return value:
! 0 - success
! 1 - internal error - see errorText for details (unless NULL passed)
! 2 - output pdf could not be opened
! 3 - chart type not specified
! 4 - chart style not specified
! 5 - no data items to chart
! 6 - no output pdf filename specified
! 7 - no bar colors specified
! 7 - no pie colors specified
!******************************************************************************

  END
